# Monthly_Income = int(input ("  Monthly Income ?  "))
# Rent = int( input (" rent   "))
# Groceries = int(input (" Groceries ") )
# Transportation = int(input (" Transportation "))
# Money_left_after_expenses= Monthly_Income - Rent -Groceries -Transportation
# print( "They are left with ",Money_left_after_expenses)
print("HELLLO "," Love",sep="\U0001F496")